//
//  CPDFShapeArrowViewController.m
//  compdfkit-tools
//
//  Copyright © 2014-2023 PDF Technologies, Inc. All Rights Reserved.
//
//  THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW
//  AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE ComPDFKit LICENSE AGREEMENT.
//  UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES.
//  This notice may not be removed from this file.
//

#import "CPDFShapeArrowViewController.h"
#import "CPDFShareCircleViewController_Header.h"
#import "CPDFArrowStyleView.h"

@interface CPDFShapeArrowViewController () <CPDFArrowStyleViewDelegate>

@property (nonatomic, strong) UILabel *arrowLabel;

@property (nonatomic, strong) UIButton *arrowBtn;

@property (nonatomic, strong) UILabel *trialLabel;

@property (nonatomic, strong) UIButton *trialBtn;

@end

@implementation CPDFShapeArrowViewController

#pragma mark - ViewController Methods

- (void)viewDidLoad {
    [super viewDidLoad];
    // Do any additional setup after loading the view.
    self.arrowLabel = [[UILabel alloc] init];
    self.arrowLabel.text = @"Start";
    [self.view addSubview:self.arrowLabel];
    
    self.arrowBtn = [[UIButton alloc] init];
    [self.arrowBtn setImage:[UIImage imageNamed:@"CPDFShapeArrowImageStart" inBundle:[NSBundle bundleForClass:self.class] compatibleWithTraitCollection:nil] forState:UIControlStateNormal];
    self.arrowBtn.autoresizingMask = UIViewAutoresizingFlexibleLeftMargin;
    [self.arrowBtn addTarget:self action:@selector(buttonItemClicked_start:) forControlEvents:UIControlEventTouchUpInside];
    [self.view addSubview:self.arrowBtn];
    
    self.trialLabel = [[UILabel alloc] init];
    self.trialLabel.text = @"End";
    self.trialLabel.autoresizingMask = UIViewAutoresizingFlexibleRightMargin;
    [self.view addSubview:self.trialLabel];
    
    self.trialBtn = [[UIButton alloc] init];
    [self.trialBtn setImage:[UIImage imageNamed:@"CPDFShapeArrowImageEnd" inBundle:[NSBundle bundleForClass:self.class] compatibleWithTraitCollection:nil] forState:UIControlStateNormal];
    [self.trialBtn addTarget:self action:@selector(buttonItemClicked_trial:) forControlEvents:UIControlEventTouchUpInside];
    self.trialBtn.autoresizingMask = UIViewAutoresizingFlexibleLeftMargin;
    [self.view addSubview:self.trialBtn];
    
    if (self.index == CPDFToolbarShapeLine) {
        self.sampleView.arrowStyleIndex = 0;
    } else if (self.index == CPDFToolbarShapeArrow) {
        self.sampleView.arrowStyleIndex = 1;
    }
    [self.fillColorSelectView removeFromSuperview];
}

- (void)viewWillLayoutSubviews {
    [super viewWillLayoutSubviews];
    self.opacitySliderView.frame = CGRectMake(10, 280, self.view.frame.size.width - 20, 90);
    self.thicknessView.frame = CGRectMake(10, 370, self.view.frame.size.width - 20, 90);
    self.dottedView.frame = CGRectMake(10, 460, self.view.frame.size.width - 20, 90);
    self.arrowLabel.frame = CGRectMake(15, 550, 60, 45);
    self.arrowBtn.frame = CGRectMake(self.view.frame.size.width - 75, 550, 60, 45);
    self.trialLabel.frame = CGRectMake(15, 595, 60, 45);
    self.trialBtn.frame = CGRectMake(self.view.frame.size.width - 75, 595, 60, 45);
}

- (void)updatePreferredContentSizeWithTraitCollection:(UITraitCollection *)traitCollection {
    self.preferredContentSize = CGSizeMake(self.view.bounds.size.width, traitCollection.verticalSizeClass == UIUserInterfaceSizeClassCompact ? 370 : 660);
}

#pragma mark - Action

- (void)buttonItemClicked_start:(id)sender {
    CPDFArrowStyleView *arrowStyleView = [[CPDFArrowStyleView alloc] initWirhTitle:@"Arrow Style"];
    arrowStyleView.frame = self.view.frame;
    arrowStyleView.delegate = self;
    arrowStyleView.autoresizingMask = UIViewAutoresizingFlexibleWidth | UIViewAutoresizingFlexibleHeight;
    [self.view addSubview:arrowStyleView];
}

- (void)buttonItemClicked_trial:(id)sender {
    CPDFArrowStyleView *arrowStyleView = [[CPDFArrowStyleView alloc] initWirhTitle:@"Trial Style"];
    arrowStyleView.frame = self.view.frame;
    arrowStyleView.delegate = self;
    arrowStyleView.autoresizingMask = UIViewAutoresizingFlexibleWidth | UIViewAutoresizingFlexibleHeight;
    [self.view addSubview:arrowStyleView];
}

#pragma mark - CPDFArrowStyleViewDelegate

- (void)arrowStyleView:(CPDFArrowStyleView *)arrowStyleView selectIndex:(NSInteger)selectIndex {
    self.sampleView.arrowStyleIndex = selectIndex;
    [self.sampleView setNeedsDisplay];
}

@end
